@@ -5,6 +5,6 @@ use crate::{command::CliCommand, error::CliError};
 pub fn daemon_command(matches: &ArgMatches) -> Result<CliCommand, CliError> {
     match matches.subcommand() {
         Some(("new", _matches)) => Ok(CliCommand::DaemonNew {}),
-        _ => Ok(CliCommand::DaemonData {}),
+        _ => Ok(CliCommand::DaemonGet {}),
     }
 }
